Changelog
---------

1.0 (2015-10-30)
~~~~~~~~~~~~~~~~

First release.
Features:

* Sending Twitch streams (video and audio)
* Reading and sending Twitch chats.

* core contributors, in alphabetical order:

  * Jonas Degrave (@317070)

* Special thanks to

  * Frederik Tejner Witte for his `great tutorial <http://www.wituz.com/tutorial-make-your-own-twitch-plays-stream.html>`_!
